Learn R Programming

lookout (version 0.1.4)

autoplot.lookoutliers: Plots outliers identified by lookout algorithm.

Description

Scatterplot of two columns from the data set with outliers highlighted.

Usage

# S3 method for lookoutliers
autoplot(object, columns = 1:2, ...)

Value

A ggplot object.

Arguments

object

The output of the function `lookout`.

columns

Which columns of the original data to plot (specified as either numbers or strings)

...

Other arguments currently ignored.

Examples

Run this code
X <- rbind(
  data.frame(x = rnorm(500),
             y = rnorm(500)),
  data.frame(x = rnorm(5, mean = 10, sd = 0.2),
             y = rnorm(5, mean = 10, sd = 0.2))
)
lo <- lookout(X)
autoplot(lo)

Run the code above in your browser using DataLab