Learn R Programming

lookout (version 0.1.4)

lookout-package: lookout: Leave One Out Kernel Density Estimates for Outlier Detection

Description

logo

Outlier detection using leave-one-out kernel density estimates and extreme value theory. The bandwidth for kernel density estimates is computed using persistent homology, a technique in topological data analysis. Using peak-over-threshold method, a generalized Pareto distribution is fitted to the log of leave-one-out kde values to identify outliers.

Arguments

Author

Maintainer: Sevvandi Kandanaarachchi sevvandik@gmail.com (ORCID)

Authors:

Other contributors:

See Also